/* audio.h
 * - processing functions
 *
 * Copyright (c) 2003 Juho Vh-Herttua <juhovh@iki.fi>
 *
 * This program is distributed under the terms of the GNU General
 * Public License, version 2. You may use, modify, and redistribute
 * it under the terms of this license. A copy should be included
 * with this source.
 */

#ifndef __AUDIO_H
#define __AUDIO_H

#include "resample.h"

typedef struct {
    resampler_state resampler;
    gint lowbits;
    gint usigned;
    gint bigendian;
    gint inchannels;
    gint outchannels;
    gint resample;
    
    gint8 *bitbuf;
    gint bitbuflen;
    
    gfloat **convbuf;
    gint convbuflen;
    
    gfloat **chanbuf;
    gint chanbuflen;
    
    gfloat **buffers;
    gint buffill;
    gint bufsize;
    
    gfloat ***srcbuf;
    gint *srcbuflen;
} process_state;

process_state *process_initialise(void);
void process_update(process_state *state, gint lowbits, gint usigned, gint be, gint inchannels, gint outchannels, gint infreq, gint outfreq);
gint process_finish(process_state *s, gfloat ***dest);
void process_clear(process_state *s);

gint process_audio(process_state *s, gint8 *buf, gint buflen, gfloat ***dest);
void convert_usigned_lowbits(process_state *s, gint8 *buf, gint buflen);
void convert_usigned(process_state *s, gint8 *buf, gint buflen);
void convert_lowbits(process_state *s, gint8 *buf, gint buflen);
void convert_endianness(process_state *s, gint8 *buf, gint buflen);
void convert_float(process_state *s, gint8 *buf, gint buflen);
void convert_channels(process_state *s, gfloat **buf, gint buflen);
void resample_buffer(process_state *s, gfloat **buf, gint buflen);

#endif

