/* configure.c
 * - load and save configuration settings
 *
 * Copyright (c) 2003 Juho Vh-Herttua <juhovh@iki.fi>
 *
 * This program is distributed under the terms of the GNU General
 * Public License, version 2. You may use, modify, and redistribute
 * it under the terms of this license. A copy should be included
 * with this source.
 */

#ifdef HAVE_CONFIG_H
 #include <config.h>
#endif

#include <xmms/configfile.h>
#include "oggcaster.h"
#include "configure.h"

oc_stream_info *config_load()
{
    ConfigFile *cfg;
    oc_stream_info *stream;
    
    cfg = xmms_cfg_open_default_file();
    stream = g_malloc0(sizeof(oc_stream_info));
    
    if (!xmms_cfg_read_string(cfg, "Oggcaster", "hostname", &stream->hostname))
        stream->hostname = g_strdup("127.0.0.1");
    if (!xmms_cfg_read_int(cfg, "Oggcaster", "port", &stream->port))
        stream->port = 8000;
    if (!xmms_cfg_read_string(cfg, "Oggcaster", "user", &stream->user))
        stream->user = g_strdup("source");
    if (!xmms_cfg_read_string(cfg, "Oggcaster", "password", &stream->password))
        stream->password = g_strdup("");
    if (!xmms_cfg_read_string(cfg, "Oggcaster", "mount", &stream->mount))
        stream->mount = g_strdup("/stream.ogg");
    
    if (!xmms_cfg_read_int(cfg, "Oggcaster", "channels", &stream->channels))
        stream->channels = 2;
    if (!xmms_cfg_read_int(cfg, "Oggcaster", "samplerate", &stream->samplerate))
        stream->samplerate = 44100;
    if (!xmms_cfg_read_boolean(cfg, "Oggcaster", "managed", &stream->managed))
        stream->managed = 0;
    if (!xmms_cfg_read_int(cfg, "Oggcaster", "bitrate_min", &stream->bitrate_min))
        stream->bitrate_min = -1;
    if (!xmms_cfg_read_int(cfg, "Oggcaster", "bitrate", &stream->bitrate))
        stream->bitrate = 128000;
    if (!xmms_cfg_read_int(cfg, "Oggcaster", "bitrate_max", &stream->bitrate_max))
        stream->bitrate_max = -1;
    if (!xmms_cfg_read_float(cfg, "Oggcaster", "quality", &stream->quality))
        stream->quality = 3;
        
    if (!xmms_cfg_read_string(cfg, "Oggcaster", "name", &stream->name))
        stream->name = g_strdup("");
    if (!xmms_cfg_read_string(cfg, "Oggcaster", "genre", &stream->genre))
        stream->genre = g_strdup("");
    if (!xmms_cfg_read_string(cfg, "Oggcaster", "description", &stream->description))
        stream->description = g_strdup("");
    
    xmms_cfg_free(cfg);
    return stream;
}

void config_save(oc_stream_info *stream)
{
	ConfigFile *cfg;
    
	cfg = xmms_cfg_open_default_file();
    
    xmms_cfg_write_string(cfg, "Oggcaster", "hostname", stream->hostname);
    xmms_cfg_write_int(cfg, "Oggcaster", "port", stream->port);
    xmms_cfg_write_string(cfg, "Oggcaster", "user", stream->user);
    xmms_cfg_write_string(cfg, "Oggcaster", "password", stream->password);
    xmms_cfg_write_string(cfg, "Oggcaster", "mount", stream->mount);
    
    xmms_cfg_write_int(cfg, "Oggcaster", "channels", stream->channels);
    xmms_cfg_write_int(cfg, "Oggcaster", "samplerate", stream->samplerate);
    xmms_cfg_write_boolean(cfg, "Oggcaster", "managed", stream->managed);
    xmms_cfg_write_int(cfg, "Oggcaster", "bitrate_min", stream->bitrate_min);
    xmms_cfg_write_int(cfg, "Oggcaster", "bitrate", stream->bitrate);
    xmms_cfg_write_int(cfg, "Oggcaster", "bitrate_max", stream->bitrate_max);
    xmms_cfg_write_float(cfg, "Oggcaster", "quality", stream->quality);
    
    xmms_cfg_write_string(cfg, "Oggcaster", "name", stream->name);
    xmms_cfg_write_string(cfg, "Oggcaster", "genre", stream->genre);
    xmms_cfg_write_string(cfg, "Oggcaster", "description", stream->description);
    
    xmms_cfg_write_default_file(cfg);
    xmms_cfg_free(cfg);
}
