/* oggcaster.c
 * - basic plugin functions and structs
 *
 * Copyright (c) 2003 Juho Vh-Herttua <juhovh@iki.fi>
 *
 * This program is distributed under the terms of the GNU General
 * Public License, version 2. You may use, modify, and redistribute
 * it under the terms of this license. A copy should be included
 * with this source.
 */

#ifndef __OGGCASTER_H
#define __OGGCASTER_H

#include <glib.h>
#include <pthread.h>
#include <ogg/ogg.h>
#include <vorbis/codec.h>
#include <shout/shout.h>
#include <xmms/plugin.h>

#include "audio.h"
#include "encode.h"
#include "resample.h"

typedef struct {
    gfloat **buf;
    gint len;
    gint channels;
    gboolean kill;
    gboolean new_encoder;
    vorbis_comment *vc;
} ref_buffer;

typedef struct _queue_item {
    ref_buffer *buf;
    struct _queue_item *next;
} queue_item;

typedef struct buffer_queue {
    queue_item *head, *tail;
    int length;
    pthread_mutex_t lock;
} buffer_queue;

typedef struct {    
    gint channels;
    gint samplerate;
    
    gboolean managed;
    gint bitrate_min;
    gint bitrate;
    gint bitrate_max;
    gfloat quality;
    gint serial;
    
    gchar *hostname;
    gint port;
    gchar *user;
    gchar *password;
    gchar *mount;
    
    gchar *name;
    gchar *genre;
    gchar *description;
} oc_stream_info;

typedef struct {
    oc_stream_info *stream;
    oc_stream_info *saved_stream;
    process_state *proc;
    vorbis_comment *vc;
    buffer_queue *queue;
    pthread_t thread;
    pthread_cond_t cond;
    pthread_mutex_t runlock;
    
    AFormat old_format;
    gint old_srate;
    gint old_channels;

    gboolean running;
    gboolean muted;
    gboolean new_connection;
    gboolean new_stream;
    gboolean new_encoder;
    
    gint timeout_tag;
    
    gint previous_song;
    gint previous_length;
} oc_state_info;

#endif
